import React from 'react'

import {
  Badge,
  Box,
  Divider,
  HStack,
  Icon,
  IconButton,
  Select,
} from '@chakra-ui/react'
import { FaArrowLeft } from 'react-icons/fa'

import { Link, back, navigate, routes, useLocation } from '@redwoodjs/router'
import { LANGUAGES } from 'src/constants'
import { useTranslation } from 'react-i18next'
import { getInitialLanguageCode } from 'src/i18n'

export const TOPBAR_HEIGHT_PX = '40px'
export const Topbar: React.FC = () => {
  const { i18n, t } = useTranslation()
  const { pathname } = useLocation()
  const initialLanguageCode = getInitialLanguageCode()

  const handleOnBack = () => {
    if (pathname === '/') {
      // @ts-ignore -- TODO
      navigate(routes.home())
    } else {
      back()
    }
  }

  const onChangeLang = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const langCode = e.target.value
    i18n.changeLanguage(langCode)
    localStorage.setItem('language', langCode)
  }

  return (
    <>
      <HStack
        h={TOPBAR_HEIGHT_PX}
        w="full"
        justifyContent="space-between"
        pr="4"
        bgColor="blue.200"
        position="sticky"
        top="0"
        spacing="0"
      >
        {pathname !== '/' ? (
          <IconButton
            aria-label="back"
            variant="unstyled"
            onClick={handleOnBack}
            icon={<Icon as={FaArrowLeft} color="gray.600" />}
          />
        ) : (
          <Box />
        )}

        <HStack>
          {/* @ts-ignore -- TODO */}
          <Link to={routes.patterns()}>
            <Badge textAlign="right" color="gray.600" variant="-2u">
              Patrones {t('home')}
            </Badge>
          </Link>
          <Select
            onChange={onChangeLang}
            defaultValue={initialLanguageCode}
            variant="unstyled"
            fontSize="xs"
          >
            {LANGUAGES.map(({ code, label }) => (
              <option key={code} value={code}>
                {label}
              </option>
            ))}
          </Select>
        </HStack>
      </HStack>
      <Divider />
    </>
  )
}
