import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'

import { Implementation } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace GetImplementationQuery {
  export type Params = { id: Implementation['id'] }

  export type Response = Implementation

  export const key = ['implementations']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (params: Params) =>
    axiosService
      .get<Response>(`/implementations/${params.id}`)
      .then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
